@@ -26,14 +26,16 @@ class SimpleStorageTestCase(base.TestCase):
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/'
                   'simple_storage.json') as f:
-            self.conn.get.return_value.json.return_value = json.load(f)
+            self.json_doc = json.load(f)
+
+        self.conn.get.return_value.json.return_value = self.json_doc
 
         self.simpl_stor = simple_storage.SimpleStorage(
             self.conn, '/redfish/v1/Systems/437XR1138R2/SimpleStorage/1',
             redfish_version='1.0.2')
 
     def test__parse_attributes(self):
-        self.simpl_stor._parse_attributes()
+        self.simpl_stor._parse_attributes(self.json_doc)
         self.assertEqual('1.0.2', self.simpl_stor.redfish_version)
         self.assertEqual('1', self.simpl_stor.identity)
         self.assertEqual('Simple Storage Controller', self.simpl_stor.name)
@@ -56,13 +58,17 @@ class SimpleStorageCollectionTestCase(base.TestCase):
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/'
                   'simple_storage_collection.json') as f:
-            self.conn.get.return_value.json.return_value = json.load(f)
+
+            self.json_doc = json.load(f)
+
+        self.conn.get.return_value.json.return_value = self.json_doc
+
         self.simpl_stor_col = simple_storage.SimpleStorageCollection(
             self.conn, '/redfish/v1/Systems/437XR1138R2/SimpleStorage',
             redfish_version='1.0.2')
 
     def test__parse_attributes(self):
-        self.simpl_stor_col._parse_attributes()
+        self.simpl_stor_col._parse_attributes(self.json_doc)
         self.assertEqual((
             '/redfish/v1/Systems/437XR1138R2/SimpleStorage/1',),
             self.simpl_stor_col.members_identities)
@@ -74,7 +80,7 @@ class SimpleStorageCollectionTestCase(base.TestCase):
         SimpleStorage_mock.assert_called_once_with(
             self.simpl_stor_col._conn,
             '/redfish/v1/Systems/437XR1138R2/SimpleStorage/1',
-            redfish_version=self.simpl_stor_col.redfish_version)
+            self.simpl_stor_col.redfish_version, None)
 
     @mock.patch.object(simple_storage, 'SimpleStorage', autospec=True)
     def test_get_members(self, SimpleStorage_mock):
@@ -82,7 +88,7 @@ class SimpleStorageCollectionTestCase(base.TestCase):
         SimpleStorage_mock.assert_called_once_with(
             self.simpl_stor_col._conn,
             '/redfish/v1/Systems/437XR1138R2/SimpleStorage/1',
-            redfish_version=self.simpl_stor_col.redfish_version)
+            self.simpl_stor_col.redfish_version, None)
         self.assertIsInstance(members, list)
         self.assertEqual(1, len(members))
 
@@ -96,6 +102,19 @@ class SimpleStorageCollectionTestCase(base.TestCase):
         self.assertEqual([4000000000000, 8000000000000],
                          self.simpl_stor_col.disks_sizes_bytes)
 
+    def test_disks_sizes_bytes_capacity_bytes_none(self):
+        self.conn.get.return_value.json.reset_mock()
+
+        with open('sushy/tests/unit/json_samples/'
+                  'simple_storage.json') as f:
+            json_doc = json.load(f)
+
+        json_doc['Devices'][0]['CapacityBytes'] = None
+        self.conn.get.return_value.json.return_value = json_doc
+
+        self.assertEqual([4000000000000],
+                         self.simpl_stor_col.disks_sizes_bytes)
+
     def test_max_size_bytes(self):
         self.conn.get.return_value.json.reset_mock()
 
